@@ -1,5 +1,5 @@
 var a00815 =
 [
     [ "PatchMap", "a00977.html", "a00977" ],
-    [ "PatchMap::QuadNode::Child", "a00985.html", "a00985" ]
+    [ "Child", "a00985.html", "a00985" ]
 ];
\ No newline at end of file
